# The COPYRIGHT file at the top level of this repository contains the full
# copyright notices and license terms.
from trytond.pool import Pool, PoolMeta

from .web import ShopWooCommerceIdMixin


class Party(ShopWooCommerceIdMixin, metaclass=PoolMeta):
    __name__ = 'party.party'

    @classmethod
    def create_from_woocommerce(cls, shop, values):
        pool = Pool()
        Address = pool.get('party.address')
        Mechanism = pool.get('party.contact_mechanism')
        party = cls()
        party.name = values['billing'].get('company')
        party.addresses = [
            Address.create_from_woocommerce(shop, values['billing']),
            # XXX: Shipment address
            ]
        if not party.name:
            party.name = party.addresses[0].party_name
        party.woocommerce_id = values['customer_id']
        mechanisms = []
        if values['billing'].get('email'):
            mechanism = Mechanism()
            mechanism.party = party
            mechanism.type = 'email'
            mechanism.value = mechanism.format_value(
                value=values['billing']['email'], type_='email')
            mechanisms.append(mechanism)
        if values['billing'].get('phone'):
            mechanism = Mechanism()
            mechanism.party = party
            mechanism.type = 'phone'
            mechanism.value = mechanism.format_value(
                value=values['billing']['phone'], type_='phone')
            mechanisms.append(mechanism)
        party.contact_mechanisms = mechanisms
        party.save()
        return party


class Address(metaclass=PoolMeta):
    __name__ = 'party.address'

    @classmethod
    def create_from_woocommerce(cls, shop, values):
        pool = Pool()
        Country = pool.get('country.country')
        Subdivision = pool.get('country.subdivision')
        address = cls()
        address.party_name = ' '.join(filter(bool, [
                        values['first_name'], values['last_name']]))
        address.street = '\n'.join(filter(bool, [
                        values['address_1'], values['address_2']]))
        address.city = values['city']
        address.zip = values['postcode']
        country = Country.search([
                ('code', '=', values['country']),
                ], limit=1)
        if country:
            address.country, = country
            subdivision = Subdivision.search([
                    ('code', '=', '%s-%s' % (
                            address.country.code, values['state'])),
                    ], limit=1)
            if subdivision:
                address.subdivision, = subdivision
        return address
