# The COPYRIGHT file at the top level of this repository contains the full
# copyright notices and license terms.
from trytond.pool import PoolMeta
from trytond.tools import slugify

from .web import ShopWooCommerceIdMixin


class Category(ShopWooCommerceIdMixin, metaclass=PoolMeta):
    __name__ = 'product.category'

    def get_woocommerce_entity(self):
        values = {
            'name': self.name,
            'slug': slugify(self.name),
            'parent': 0,
            }
        if self.parent:
            if self.parent.woocommerce_id:
                values['parent'] = self.parent.woocommerce_id
            else:
                return
        return values


class Product(ShopWooCommerceIdMixin, metaclass=PoolMeta):
    __name__ = 'product.product'

    def get_woocommerce_entity(self):
        short_description = description = self.description
        lines = description.splitlines()
        if len(lines) > 1:
            short_description = lines[0]
            description = '\n'.join(lines[1:])
        values = {
            'name': self.name,
            'type': 'simple',
            'regular_price': str(self.list_price),
            'sale_price': str(self.list_price),
            'description': description,
            'short_description': short_description,
            'status': 'publish',
            'manage_stock': 'true',
            'stock_quantity': 12,
        }
        if self.code:
            values['sku'] = self.code
        categories = []
        for category in self.categories:
            if category.woocommerce_id:
                categories.append({'id': category.woocommerce_id})
        values['categories'] = categories
        return values
